@@ -1,8 +1,8 @@
 package AFS::ACL;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)$RCS-Id: src/ACL/ACL.pm 7a64d4d Wed May 1 22:05:49 2013 +0200 Norbert E Gruener$"
+# RCS-Id: "@(#)ACL.pm,v 1.3 2002/07/04 05:59:18 nog Exp"
 #
-# © 2001-2011 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
@@ -13,7 +13,7 @@ use AFS ();
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = 'v2.6.4';
+$VERSION = sprintf("%d.%02d", q/1.3/ =~ /(\d+)\.(\d+)/);
 
 sub new {
     my ($this, $class);
@@ -62,7 +62,7 @@ sub retrieve {
     my $follow = shift;
 
     $follow = 1 unless defined $follow;
-    AFS::_getacl($path, $follow);
+    AFS::getacl($path, $follow);
 }
 
 sub modifyacl {
@@ -70,10 +70,10 @@ sub modifyacl {
     my $path   = shift;
     my $follow = shift;
 
-    my $newacl;
+    my($newacl);
 
     $follow = 1 unless defined $follow;
-    if ($newacl = AFS::_getacl($path, $follow)) {
+    if ($newacl = AFS::getacl($path, $follow)) {
         $newacl->add($self);
         AFS::setacl($path, $newacl, $follow);
     }
@@ -86,10 +86,10 @@ sub copyacl {
     my $to     = shift;
     my $follow = shift;
 
-    my $acl;
+    my($acl);
 
     $follow = 1 unless defined $follow;
-    if ($acl = AFS::_getacl($from, $follow)) { AFS::setacl($to, $acl, $follow); }
+    if ($acl = AFS::getacl($from, $follow)) { AFS::setacl($to, $acl, $follow); }
     else { return 0; }
 }
 
@@ -98,12 +98,11 @@ sub cleanacl {
     my $path   = shift;
     my $follow = shift;
 
-    my $acl;
+    my($acl);
 
     $follow = 1 unless defined $follow;
-    if (! defined ($acl = AFS::_getacl($path, $follow))) { return 0; }
-    if ($acl->is_clean) { return 1; }
-    AFS::setacl($path, $acl, $follow);
+    if ($acl = AFS::getacl($path, $follow)) { AFS::setacl($path, $acl, $follow); }
+    else { return 0; }
 }
 
 sub crights {
@@ -126,11 +125,11 @@ sub rights2ascii {
 
 # old form  DEPRECATED !!!!
 sub addacl {
-    my $self = shift;
-    my $macl = shift;
+    my ($self, $macl) = @_;
+    my ($key);
 
-    foreach my $key ($macl->keys)  { $self->set($key, $macl->get($key)); }
-    foreach my $key ($macl->nkeys) { $self->nset($key, $macl->nget($key)); }
+    foreach $key ($macl->keys)  { $self->set($key, $macl->get($key)); }
+    foreach $key ($macl->nkeys) { $self->nset($key, $macl->nget($key)); }
     return $self;
 }
 
@@ -143,12 +142,6 @@ sub add {
     return $self;
 }
 
-sub is_clean {
-    my $self = shift;
-
-    foreach ($self->get_users, $self->nget_users) { return 0 if (m/^-?\d+$/); }
-    return 1;
-}
 
 # comment Roland Schemers: I hope I don't have to debug these :-)
 sub empty      { $_[0] = bless [ {},{} ]; }
