@@ -1,13 +1,13 @@
 package AFS;
 
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)$RCS-Id: src/AFS.pm 7a64d4d Wed May 1 22:05:49 2013 +0200 Norbert E Gruener$"
+# RCS-Id: "@(#)AFS.pm,v 2.2 2002/07/08 08:42:26 nog Exp"
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #
-# © 2001-2011 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
-# © 1994 Board of Trustees, Leland Stanford Jr. University.
+# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  1994 Board of Trustees, Leland Stanford Jr. University.
 #
 #  The original library is covered by the following copyright:
 #
@@ -24,17 +24,15 @@ package AFS;
 #     WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #------------------------------------------------------------------------------
 
-use Carp;
-
 require Exporter;
 require AutoLoader;
 require DynaLoader;
 
-use vars qw(@ISA $VERSION);
+use vars qw(@ISA $VERSION $REVISION);
 
-@ISA = qw(Exporter AutoLoader DynaLoader);
-
-$VERSION = 'v2.6.4';
+@ISA      = qw(Exporter AutoLoader DynaLoader);
+$VERSION  = do{my@r=q/V_2_01/=~/\d+/g;sprintf '%d.'.'%02d'x$#r,@r};
+$REVISION = sprintf("%d.%02d", q/2.2/ =~ /(\d+)\.(\d+)/);
 
 @CELL = qw (
             configdir
@@ -174,8 +172,6 @@ sub get_server_version {
                 'bos' => 7007,
                );
 
-    if (! defined $port{$server}) { die "Server $server unknown ...\n"; }
-
     $hostname = 'localhost' unless defined $hostname;
     $verbose  = 0           unless defined $verbose;
 
@@ -184,25 +180,23 @@ sub get_server_version {
 
 
 # acl helpers...
-sub getacl { require AFS::ACL; AFS::ACL->import; AFS::_getacl(@_); }
+ sub modifyacl {
+     my($path, $macl) = @_;
+     my($acl);
 
-sub modifyacl {
-    my($path, $macl) = @_;
-    my($acl);
-
-    if ($acl = getacl($path)) {
-        $acl->addacl($macl);
-        return setacl($path, $acl);
-    }
-    else { return 0; }
-}
+     if ($acl = getacl($path)) {
+         $acl->addacl($macl);
+         return setacl($path, $acl);
+     }
+     else { return 0; }
+ }
 
 sub copyacl {
     my($from, $to, $follow) = @_;
     my($acl);
 
     $follow = 1 unless defined $follow;
-    if ($acl = _getacl($from, $follow)) { return setacl($to, $acl, $follow); }
+    if ($acl = getacl($from, $follow)) { return setacl($to, $acl, $follow); }
     else { return 0; }
 
 }
@@ -212,12 +206,12 @@ sub cleanacl {
     my($acl);
 
     $follow = 1 unless defined $follow;
-    if ($acl = _getacl($path, $follow)) { return setacl($path, $acl, $follow); }
+    if ($acl = getacl($path, $follow)) { return setacl($path, $acl, $follow); }
     else { return 0; }
 }
 
-# package AFS::PTS_SERVER;
-# sub new { AFS::PTS->_new(@_); }
+package AFS::PTS_SERVER;
+sub new { AFS::PTS->_new(@_); }
 
 use AFS::KTC_PRINCIPAL;
 # package AFS::KTC_PRINCIPAL;
@@ -243,42 +237,29 @@ use AFS::KAS;
 package AFS;
 
 sub AUTOLOAD {
-    # This AUTOLOAD is used to 'autoload' constants from the constant()
-    # XS function.  If a constant is not found then control is passed
-    # to the AUTOLOAD in AutoLoader.
-    # taken from perl v5.005_02 for backward compatibility
-
-    my $constname;
+    if (@_ > 1) {
+	$AutoLoader::AUTOLOAD = $AUTOLOAD;
+	goto &AutoLoader::AUTOLOAD;
+    }
+    local($constname);
 
     ($constname = $AUTOLOAD) =~ s/.*:://;
-    croak "& not defined" if $constname eq 'constant';
-    my $val = constant($constname, @_ ? $_[0] : 0);
+    $val = constant($constname);
     if ($! != 0) {
-	if ($! =~ /Invalid/ || $!{EINVAL}) {
+	if ($! =~ /Invalid/) {
 	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
 	    goto &AutoLoader::AUTOLOAD;
 	}
 	else {
-	    croak "Your vendor has not defined AFS macro $constname";
-	}
-    }
-    {
-	no strict 'refs';
-	# Fixed between 5.005_53 and 5.005_61
-	if ($] >= 5.00561) {
-	    *$AUTOLOAD = sub () { $val };
-	}
-	else {
-	    *$AUTOLOAD = sub { $val };
+	    ($pack, $file, $line) = caller;
+	    die "Your vendor has not defined AFS macro $constname, used at $file line $line.";
 	}
     }
+    if ($val =~ /^-?\d+/) { eval "sub $AUTOLOAD { $val }"; }
+    else                  { eval "sub $AUTOLOAD { \"$val\" }"; }
     goto &$AUTOLOAD;
 }
 
-END {
-    AFS::_finalize();
-}
-
 bootstrap AFS;
 
 # Preloaded methods go here.  Autoload methods go after __END__, and are
